@@ -1,7 +1,8 @@
 #pragma once
 
 #include <chrono>
-#include <sstream>
+#include <map>
+#include <set>
 #include <string>
 #include <vector>
 
@@ -14,18 +15,22 @@ namespace caps_log::log {
  */
 class LogFile {
     std::string m_content;
+    std::map<std::string, std::set<std::string>> m_tagsPerSection;
     std::chrono::year_month_day m_date;
 
   public:
     LogFile(const std::chrono::year_month_day &date, std::string content)
         : m_date{date}, m_content{std::move(content)} {}
 
+    LogFile &parse(bool skipFirstLine = true);
+
     std::string getContent() const { return m_content; }
     std::chrono::year_month_day getDate() const { return m_date; }
 
-    std::vector<std::string> readTagTitles() const;
-
-    std::vector<std::string> readSectionTitles(bool skipFirstLine = true) const;
+    static constexpr std::string_view kRootSectionKey = "<root section>";
+    std::set<std::string> getSectionTitles() const;
+    std::set<std::string> getTagTitles() const;
+    std::map<std::string, std::set<std::string>> getTagsPerSection() const;
 };
 
 } // namespace caps_log::log
