@@ -21,7 +21,7 @@ class AnnualView : public AnnualViewBase {
     InputHandlerBase *m_handler{nullptr};
     ftxui::ScreenInteractive m_screen;
 
-    // UI compontents visible to the user
+    // UI components visible to the user
     std::shared_ptr<Calendar> m_calendarButtons;
     std::shared_ptr<WindowedMenu> m_tagsMenu, m_sectionsMenu;
     std::shared_ptr<Preview> m_preview = std::make_unique<Preview>();
@@ -59,7 +59,9 @@ class AnnualView : public AnnualViewBase {
     void setHighlightedDates(const utils::date::Dates *map) override { m_highlightedDates = map; }
     void setEventDates(const CalendarEvents *events) override { m_eventDates = events; }
 
-    void setPreviewString(const std::string &string) override { m_preview->setContent(string); }
+    void setPreviewString(const std::string &title, const std::string &string) override {
+        m_preview->setContent(title, string);
+    }
 
     void withRestoredIO(std::function<void()> func) override { m_screen.WithRestoredIO(func)(); }
 
