@@ -7,6 +7,7 @@ namespace caps_log::view {
 class Preview : public ftxui::ComponentBase {
     int m_topLineIndex = 0;
     ftxui::Elements m_lines;
+    ftxui::Element m_title = ftxui::text("log preview");
 
   public:
     ftxui::Element Render() override;
@@ -14,7 +15,7 @@ class Preview : public ftxui::ComponentBase {
     bool OnEvent(ftxui::Event event) override;
 
     void resetScroll();
-    void setContent(const std::string &str);
+    void setContent(const std::string &title, const std::string &str);
 };
 
 } // namespace caps_log::view
